# pyqt-single-image-graphics-view
PyQt one image only QGraphicsView

## Requirements
* PyQt5 >= 5.8

## Setup
`python -m pip install pyqt-single-image-graphics-view`

## Method Overview
* `setFilename(filename: str)`
* `setPixmap(p: QPixmap)`

## See Also
* <a href="https://github.com/yjg30737/pyqt-fitting-graphics-view.git">pyqt-fitting-graphics-view</a>
